#ifndef DSPAUDIOIN_H_INCLUDED
#define DSPAUDIOIN_H_INCLUDED

#include <dspaudio.h>

#include "../config.h"

class DspOut;

class DspAudioIn : public DspAudio
{
#ifndef QT_THREAD_SUPPORT
	Q_OBJECT
#endif
public:
	DspAudioIn( DspOut *in, DspOut *out );
	~DspAudioIn( void );

	/**
	 * Just do one tick, for non-threaded implementations.
	 */
	virtual void timerTick( void );

#ifndef QT_THREAD_SUPPORT
	virtual void start( void );

private slots:
	virtual void timeout( void );

#endif

private:
	int udp_failures;
};

#endif // DSPAUDIOIN_H_INCLUDED
